---
name: Bug Report
about: Create a bug report to help us improve the tool
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Please provide us with a minimal failing example e.g. a failing padframe yaml configuration file.

**Expected behavior**
A clear and concise description of what you expected to happen.

**Logs**
If applicable, add log output to help explain your problem.

**Additional context**
Add any other context about the problem here.
